@@ -4,13 +4,14 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2012 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2012 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2013 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
-# Meinert Jordan, Armin Köhler, Edwin Lunando, Joshua Miller, Stevan Pettit,  #
-# Andreas Preikschat, Mattias Põldaru, Christian Richter, Philip Ridout,      #
-# Simon Scudder, Jeffrey Smith, Maikel Stuivenberg, Martin Thompson, Jon      #
-# Tibble, Dave Warnock, Frode Woldsund                                        #
+# Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
+# Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
+# Christian Richter, Philip Ridout, Simon Scudder, Jeffrey Smith,             #
+# Maikel Stuivenberg, Martin Thompson, Jon Tibble, Dave Warnock,              #
+# Frode Woldsund, Martin Zibricky                                             #
 # --------------------------------------------------------------------------- #
 # This program is free software; you can redistribute it and/or modify it     #
 # under the terms of the GNU General Public License as published by the Free  #
@@ -25,6 +26,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc., 59  #
 # Temple Place, Suite 330, Boston, MA 02111-1307 USA                          #
 ###############################################################################
+
 """
 The :mod:`db` module provides the core database functionality for OpenLP
 """
@@ -83,11 +85,13 @@ def upgrade_db(url, upgrade):
         Provides a class for the metadata table.
         """
         pass
-    load_changes = True
+    load_changes = False
+    tables = []
     try:
         tables = upgrade.upgrade_setup(metadata)
+        load_changes = True
     except (SQLAlchemyError, DBAPIError):
-        load_changes = False
+        pass
     metadata_table = Table(u'metadata', metadata,
         Column(u'key', types.Unicode(64), primary_key=True),
         Column(u'value', types.UnicodeText(), default=None)
@@ -97,6 +101,7 @@ def upgrade_db(url, upgrade):
     version_meta = session.query(Metadata).get(u'version')
     if version_meta is None:
         version_meta = Metadata.populate(key=u'version', value=u'0')
+        session.add(version_meta)
         version = 0
     else:
         version = int(version_meta.value)
@@ -109,17 +114,17 @@ def upgrade_db(url, upgrade):
             try:
                 getattr(upgrade, u'upgrade_%d' % version) \
                     (session, metadata, tables)
-                version_meta.value = unicode(version)
             except (SQLAlchemyError, DBAPIError):
                 log.exception(u'Could not run database upgrade script '
                     '"upgrade_%s", upgrade process has been halted.', version)
                 break
+            version_meta.value = unicode(version)
+            session.commit()
             version += 1
     else:
         version_meta = Metadata.populate(key=u'version',
             value=int(upgrade.__version__))
-    session.add(version_meta)
-    session.commit()
+        session.commit()
     return int(version_meta.value), upgrade.__version__
 
 
