@@ -4,13 +4,14 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2012 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2012 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2013 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
-# Meinert Jordan, Armin Köhler, Edwin Lunando, Joshua Miller, Stevan Pettit,  #
-# Andreas Preikschat, Mattias Põldaru, Christian Richter, Philip Ridout,      #
-# Simon Scudder, Jeffrey Smith, Maikel Stuivenberg, Martin Thompson, Jon      #
-# Tibble, Dave Warnock, Frode Woldsund                                        #
+# Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
+# Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
+# Christian Richter, Philip Ridout, Simon Scudder, Jeffrey Smith,             #
+# Maikel Stuivenberg, Martin Thompson, Jon Tibble, Dave Warnock,              #
+# Frode Woldsund, Martin Zibricky                                             #
 # --------------------------------------------------------------------------- #
 # This program is free software; you can redistribute it and/or modify it     #
 # under the terms of the GNU General Public License as published by the Free  #
@@ -108,36 +109,47 @@ class Ui_AboutDialog(object):
         contributors = [u'Gerald "jerryb" Britton',
             u'Samuel "MrGamgee" Findlay', u'Scott "sguerrieri" Guerrieri',
             u'Matthias "matthub" Hub', u'Meinert "m2j" Jordan',
-            u'Armin "orangeshirt" K\xf6hler', u'Edwin "edwinlunando" Lunando',
+            u'Armin "orangeshirt" K\xf6hler', u'Erik "luen" Lundin',
+            u'Edwin "edwinlunando" Lunando', u'Brian "brianmeyer" Meyer',
             u'Joshua "milleja46" Miller', u'Stevan "ElderP" Pettit',
             u'Mattias "mahfiaz" P\xf5ldaru', u'Christian "crichter" Richter',
             u'Philip "Phill" Ridout', u'Simon "samscudder" Scudder',
             u'Jeffrey "whydoubt" Smith', u'Maikel Stuivenberg',
-            u'Dave "Dave42W" Warnock', u'Frode "frodus" Woldsund']
+            u'Dave "Dave42W" Warnock', u'Frode "frodus" Woldsund',
+            u'Martin "matysek" Zibricky']
         testers = [u'Philip "Phill" Ridout', u'Wesley "wrst" Stout',
             u'John "jseagull1" Cegalis (lead)']
         packagers = ['Thomas "tabthorpe" Abthorpe (FreeBSD)',
             u'Tim "TRB143" Bentley (Fedora and Android)',
             u'Matthias "matthub" Hub (Mac OS X)',
+            u'Joseph "jdmulloy" Mulloy (openSUSE)',
             u'Stevan "ElderP" Pettit (Windows)',
-            u'Raoul "superfly" Snyman (Ubuntu)',
+            u'Raoul "superfly" Snyman (Debian, Ubuntu)',
             u'Garrett "floft" Wilson (Arch Linux)']
         translators = {
             u'af': [u'Johan "nuvolari" Mynhardt'],
+            u'cs': [u'Martin "matysek" Zibricky'],
+            u'da': [u'Henrik "Hsonesson" Sonesson'],
             u'de': [u'Patrick "madmuffin" Br\xfcckner',
                 u'Meinert "m2j" Jordan', u'Andreas "googol" Preikschat',
                 u'Christian "crichter" Richter'],
             u'en_GB': [u'Tim "TRB143" Bentley', u'Jonathan "gushie" Corwin'],
-            u'en_ZA': [u'Raoul "superfly" Snyman'],
+            u'en_ZA': [u'Raoul "superfly" Snyman',
+                       u'Johan "nuvolari" Mynhardt'],
+            u'el': [u'Alexander Siozos'],
+            u'es': [u'Josu\xe9 Z\xfa\xf1iga',u'Christian Gonzalez'],
             u'et': [u'Mattias "mahfiaz" P\xf5ldaru'],
-            u'fr': [u'Stephan\xe9 "stbrunner" Brunner'],
+            u'fr': [u'Stephan\xe9 "stbrunner" Brunner', u'Jeremie'],
             u'hu': [u'Gyuris Gell\xe9rt'],
-            u'ja': [u'Kunio "Kunio" Nakamaru'],
+            u'ja': [u'Kunio "Kunio" Nakamaru', u'Chris Haris'],
             u'nb': [u'Atle "pendlaren" Weibell', u'Frode "frodus" Woldsund'],
             u'nl': [u'Arjen "typovar" van Voorst'],
-            u'pt_BR': [u'Rafael "rafaellerm" Lerm', u'Gustavo Bim',
-                u'Simon "samscudder" Scudder'],
-            u'ru': [u'Sergey "ratz" Ratz']
+            u'pt_BR': [u'David Mederiros',u'Rafael "rafaellerm" Lerm',
+                       u'Eduardo Levi Chaves',
+                       u'Gustavo Bim', u'Rog\xeanio Bel\xe9m', u'Samuel'
+                u'Simon "samscudder" Scudder', u'Van Der Fran'],
+            u'ru': [u'Sergey "ratz" Ratz'],
+            u'sv': [u'Erik "luen" Lundin']
         }
         documentors = [u'Wesley "wrst" Stout',
             u'John "jseagull1" Cegalis (lead)']
@@ -160,12 +172,20 @@ class Ui_AboutDialog(object):
             'Translators\n'
             '    Afrikaans (af)\n'
             '        %s\n'
+            '    Czeck (cs)\n'
+            '        %s\n'
+            '    Danish (da)\n'
+            '        %s\n'
             '    German (de)\n'
             '        %s\n'
+            '    Greek (el)\n'
+            '        %s\n'
             '    English, United Kingdom (en_GB)\n'
             '        %s\n'
             '    English, South Africa (en_ZA)\n'
             '        %s\n'
+            '    Spanish (es)\n'
+            '        %s\n'
             '    Estonian (et)\n'
             '        %s\n'
             '    French (fr)\n'
@@ -182,13 +202,15 @@ class Ui_AboutDialog(object):
             '        %s\n'
             '    Russian (ru)\n'
             '        %s\n'
+            '    Swedish (sv)\n'
+            '        %s\n'
             '\n'
             'Documentation\n'
             '    %s\n'
             '\n'
             'Built With\n'
             '    Python: http://www.python.org/\n'
-            '    Qt4: http://qt.nokia.com/\n'
+            '    Qt4: http://qt.digia.com/\n'
             '    PyQt4: http://www.riverbankcomputing.co.uk/software/pyqt/'
             'intro\n'
             '    Oxygen Icons: http://oxygen-icons.org/\n'
@@ -205,9 +227,13 @@ class Ui_AboutDialog(object):
             '    He has set us free.')) % (lead, u'\n    '.join(developers),
             u'\n    '.join(contributors), u'\n    '.join(testers),
             u'\n    '.join(packagers), u'\n        '.join(translators[u'af']),
+            u'\n        '.join(translators[u'cs']),
+            u'\n        '.join(translators[u'da']),
             u'\n        '.join(translators[u'de']),
+            u'\n        '.join(translators[u'el']),
             u'\n        '.join(translators[u'en_GB']),
             u'\n        '.join(translators[u'en_ZA']),
+            u'\n        '.join(translators[u'es']),
             u'\n        '.join(translators[u'et']),
             u'\n        '.join(translators[u'fr']),
             u'\n        '.join(translators[u'hu']),
@@ -216,19 +242,22 @@ class Ui_AboutDialog(object):
             u'\n        '.join(translators[u'nl']),
             u'\n        '.join(translators[u'pt_BR']),
             u'\n        '.join(translators[u'ru']),
+            u'\n        '.join(translators[u'sv']),
             u'\n    '.join(documentors)))
         self.aboutNotebook.setTabText(
             self.aboutNotebook.indexOf(self.creditsTab),
             translate('OpenLP.AboutForm', 'Credits'))
         copyright = unicode(translate('OpenLP.AboutForm',
-            'Copyright \xa9 2004-2012 %s\n'
-            'Portions copyright \xa9 2004-2012 %s')) % (u'Raoul Snyman',
+            'Copyright \xa9 2004-2013 %s\n'
+            'Portions copyright \xa9 2004-2013 %s')) % (u'Raoul Snyman',
             u'Tim Bentley, Gerald Britton, Jonathan Corwin, Samuel Findlay, '
             u'Michael Gorven, Scott Guerrieri, Matthias Hub, Meinert Jordan, '
-            u'Armin K\xf6hler, Edwin Lunando, Joshua Miller, Stevan Pettit, '
-            u'Andreas Preikschat, Mattias P\xf5ldaru, Christian Richter, '
+            u'Armin K\xf6hler, Erik Lundin, Edwin Lunando, Joshua Miller, '
+            u'Brian T. Meyer, Stevan Pettit, Andreas Preikschat, '
+            u'Mattias P\xf5ldaru, Christian Richter, '
             u'Philip Ridout, Simon Scudder, Jeffrey Smith, Maikel Stuivenberg, '
-            u'Martin Thompson, Jon Tibble, Dave Warnock, Frode Woldsund')
+            u'Martin Thompson, Jon Tibble, Dave Warnock, Frode Woldsund, '
+            u'Martin Zibricky')
         licence = translate('OpenLP.AboutForm',
             'This program is free software; you can redistribute it and/or '
             'modify it under the terms of the GNU General Public License as '
