@@ -4,13 +4,14 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2012 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2012 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2013 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
-# Meinert Jordan, Armin Köhler, Edwin Lunando, Joshua Miller, Stevan Pettit,  #
-# Andreas Preikschat, Mattias Põldaru, Christian Richter, Philip Ridout,      #
-# Simon Scudder, Jeffrey Smith, Maikel Stuivenberg, Martin Thompson, Jon      #
-# Tibble, Dave Warnock, Frode Woldsund                                        #
+# Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
+# Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
+# Christian Richter, Philip Ridout, Simon Scudder, Jeffrey Smith,             #
+# Maikel Stuivenberg, Martin Thompson, Jon Tibble, Dave Warnock,              #
+# Frode Woldsund, Martin Zibricky                                             #
 # --------------------------------------------------------------------------- #
 # This program is free software; you can redistribute it and/or modify it     #
 # under the terms of the GNU General Public License as published by the Free  #
@@ -177,8 +178,10 @@ class FirstTimeForm(QtGui.QWizard, Ui_FirstTimeWizard):
             return FirstTimePage.Progress
         elif self.currentId() == FirstTimePage.Themes:
             Receiver.send_message(u'cursor_busy')
+            Receiver.send_message(u'openlp_process_events')
             while not self.themeScreenshotThread.isFinished():
                 time.sleep(0.1)
+                Receiver.send_message(u'openlp_process_events')
             # Build the screenshot icons, as this can not be done in the thread.
             self._buildThemeScreenshots()
             Receiver.send_message(u'cursor_normal')
@@ -188,10 +191,11 @@ class FirstTimeForm(QtGui.QWizard, Ui_FirstTimeWizard):
 
     def onCurrentIdChanged(self, pageId):
         """
-        Detects Page changes and updates as approprate.
+        Detects Page changes and updates as appropriate.
         """
         # Keep track of the page we are at.  Triggering "Cancel" causes pageId
         # to be a -1.
+        Receiver.send_message(u'openlp_process_events')
         if pageId != -1:
             self.lastId = pageId
         if pageId == FirstTimePage.Plugins:
@@ -227,10 +231,12 @@ class FirstTimeForm(QtGui.QWizard, Ui_FirstTimeWizard):
                 self.cancelButton.setVisible(False)
         elif pageId == FirstTimePage.Progress:
             Receiver.send_message(u'cursor_busy')
+            self.repaint()
+            Receiver.send_message(u'openlp_process_events')
+            # Try to give the wizard a chance to redraw itself
+            time.sleep(0.2)
             self._preWizard()
-            Receiver.send_message(u'openlp_process_events')
             self._performWizard()
-            Receiver.send_message(u'openlp_process_events')
             self._postWizard()
             Receiver.send_message(u'cursor_normal')
             Receiver.send_message(u'openlp_process_events')
@@ -263,8 +269,8 @@ class FirstTimeForm(QtGui.QWizard, Ui_FirstTimeWizard):
         """
         Receiver.send_message(u'cursor_busy')
         self._performWizard()
-        Receiver.send_message(u'openlp_process_events')
         Receiver.send_message(u'cursor_normal')
+        Receiver.send_message(u'openlp_process_events')
         Settings().setValue(u'general/has run wizard',
             QtCore.QVariant(True))
         self.close()
@@ -344,6 +350,7 @@ class FirstTimeForm(QtGui.QWizard, Ui_FirstTimeWizard):
         Receiver.send_message(u'openlp_process_events')
         # Loop through the songs list and increase for each selected item
         for i in xrange(self.songsListWidget.count()):
+            Receiver.send_message(u'openlp_process_events')
             item = self.songsListWidget.item(i)
             if item.checkState() == QtCore.Qt.Checked:
                 filename = item.data(QtCore.Qt.UserRole).toString()
@@ -352,6 +359,7 @@ class FirstTimeForm(QtGui.QWizard, Ui_FirstTimeWizard):
         # Loop through the Bibles list and increase for each selected item
         iterator = QtGui.QTreeWidgetItemIterator(self.biblesTreeWidget)
         while iterator.value():
+            Receiver.send_message(u'openlp_process_events')
             item = iterator.value()
             if item.parent() and item.checkState(0) == QtCore.Qt.Checked:
                 filename = item.data(0, QtCore.Qt.UserRole).toString()
@@ -360,6 +368,7 @@ class FirstTimeForm(QtGui.QWizard, Ui_FirstTimeWizard):
             iterator += 1
         # Loop through the themes list and increase for each selected item
         for i in xrange(self.themesListWidget.count()):
+            Receiver.send_message(u'openlp_process_events')
             item = self.themesListWidget.item(i)
             if item.checkState() == QtCore.Qt.Checked:
                 filename = item.data(QtCore.Qt.UserRole).toString()
@@ -381,6 +390,10 @@ class FirstTimeForm(QtGui.QWizard, Ui_FirstTimeWizard):
             self.progressPage.setTitle(translate('OpenLP.FirstTimeWizard',
                 'Setting Up'))
             self.progressPage.setSubTitle(u'Setup complete.')
+        self.repaint()
+        Receiver.send_message(u'openlp_process_events')
+        # Try to give the wizard a chance to repaint itself
+        time.sleep(0.1)
 
     def _postWizard(self):
         """
@@ -418,8 +431,11 @@ class FirstTimeForm(QtGui.QWizard, Ui_FirstTimeWizard):
             'Enabling selected plugins...'))
         self._setPluginStatus(self.songsCheckBox, u'songs/status')
         self._setPluginStatus(self.bibleCheckBox, u'bibles/status')
-        self._setPluginStatus(self.presentationCheckBox,
-            u'presentations/status')
+        # TODO Presentation plugin is not yet working on Mac OS X.
+        # For now just ignore it.
+        if sys.platform != 'darwin':
+            self._setPluginStatus(self.presentationCheckBox,
+                u'presentations/status')
         self._setPluginStatus(self.imageCheckBox, u'images/status')
         self._setPluginStatus(self.mediaCheckBox, u'media/status')
         self._setPluginStatus(self.remoteCheckBox, u'remotes/status')
