@@ -4,13 +4,14 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2011 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2011 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2013 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
-# Meinert Jordan, Armin Köhler, Edwin Lunando, Joshua Miller, Stevan Pettit,  #
-# Andreas Preikschat, Mattias Põldaru, Christian Richter, Philip Ridout,      #
-# Simon Scudder, Jeffrey Smith, Maikel Stuivenberg, Martin Thompson, Jon      #
-# Tibble, Dave Warnock, Frode Woldsund                                        #
+# Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
+# Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
+# Christian Richter, Philip Ridout, Simon Scudder, Jeffrey Smith,             #
+# Maikel Stuivenberg, Martin Thompson, Jon Tibble, Dave Warnock,              #
+# Frode Woldsund, Martin Zibricky                                             #
 # --------------------------------------------------------------------------- #
 # This program is free software; you can redistribute it and/or modify it     #
 # under the terms of the GNU General Public License as published by the Free  #
@@ -28,6 +29,7 @@
 
 import logging
 import os
+import sys
 from PyQt4 import QtCore, QtGui
 
 from openlp.core.lib import OpenLPToolbar, Receiver, translate
@@ -105,8 +107,7 @@ class MediaController(object):
             AppLocation.get_directory(AppLocation.AppDir),
             u'core', u'ui', u'media')
         for filename in os.listdir(controller_dir):
-            if filename.endswith(u'player.py') and not \
-                filename == 'media_player.py':
+            if filename.endswith(u'player.py'):
                 path = os.path.join(controller_dir, filename)
                 if os.path.isfile(path):
                     modulename = u'openlp.core.ui.media.' + \
@@ -114,7 +115,9 @@ class MediaController(object):
                     log.debug(u'Importing controller %s', modulename)
                     try:
                         __import__(modulename, globals(), locals(), [])
-                    except ImportError:
+                    # On some platforms importing vlc.py might cause
+                    # also OSError exceptions. (e.g. Mac OS X)
+                    except (ImportError, OSError):
                         log.warn(u'Failed to import %s on path %s',
                             modulename, path)
         controller_classes = MediaPlayer.__subclasses__()
@@ -142,13 +145,18 @@ class MediaController(object):
         if not self.curDisplayMediaPlayer.keys():
             self.timer.stop()
         else:
+            any_active = False
             for display in self.curDisplayMediaPlayer.keys():
                 self.curDisplayMediaPlayer[display].resize(display)
                 self.curDisplayMediaPlayer[display].update_ui(display)
                 if self.curDisplayMediaPlayer[display].state == \
-                    MediaState.Playing:
-                    return
-        # no players are active anymore
+                        MediaState.Playing:
+                    any_active = True
+            # There are still any active players - no need to stop timer.
+            if any_active:
+                return
+
+        # No players are active anymore.
         for display in self.curDisplayMediaPlayer.keys():
             if self.curDisplayMediaPlayer[display].state != MediaState.Paused:
                 display.controller.seekSlider.setSliderPosition(0)
@@ -287,7 +295,8 @@ class MediaController(object):
         """
         player.resize(display)
 
-    def video(self, controller, file, muted, isBackground, hidden=False):
+    def video(self, controller, file, muted, isBackground, hidden=False,
+            isInfo=False, controlsVisible=True):
         """
         Loads and starts a video to run with the option of sound
         """
@@ -345,14 +354,16 @@ class MediaController(object):
         elif Settings().value(u'general/auto unblank',
             QtCore.QVariant(False)).toBool():
             autoplay = True
-        if autoplay:
+        # Start playback only for visible widgets. If we need just load a video
+        # and get video information, do not start playback.
+        if autoplay and not isInfo:
             if not self.video_play([controller]):
                 critical_error_message_box(
                     translate('MediaPlugin.MediaItem', 'Unsupported File'),
                     unicode(translate('MediaPlugin.MediaItem',
                     'Unsupported File')))
                 return False
-        self.set_controls_visible(controller, True)
+        self.set_controls_visible(controller, controlsVisible)
         log.debug(u'use %s controller' % self.curDisplayMediaPlayer[display])
         return True
 
@@ -403,9 +414,13 @@ class MediaController(object):
         """
         log.debug(u'video_play')
         controller = msg[0]
+        controller.seekSlider.blockSignals(True)
+        controller.volumeSlider.blockSignals(True)
         for display in self.curDisplayMediaPlayer.keys():
             if display.controller == controller:
                 if not self.curDisplayMediaPlayer[display].play(display):
+                    controller.seekSlider.blockSignals(False)
+                    controller.volumeSlider.blockSignals(False)
                     return False
                 if status:
                     display.frame.evaluateJavaScript(u'show_blank("desktop");')
@@ -417,6 +432,8 @@ class MediaController(object):
         # Start Timer for ui updates
         if not self.timer.isActive():
             self.timer.start()
+        controller.seekSlider.blockSignals(False)
+        controller.volumeSlider.blockSignals(False)
         return True
 
     def video_pause(self, msg):
