@@ -4,13 +4,14 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2012 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2012 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2013 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
-# Meinert Jordan, Armin Köhler, Edwin Lunando, Joshua Miller, Stevan Pettit,  #
-# Andreas Preikschat, Mattias Põldaru, Christian Richter, Philip Ridout,      #
-# Simon Scudder, Jeffrey Smith, Maikel Stuivenberg, Martin Thompson, Jon      #
-# Tibble, Dave Warnock, Frode Woldsund                                        #
+# Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
+# Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
+# Christian Richter, Philip Ridout, Simon Scudder, Jeffrey Smith,             #
+# Maikel Stuivenberg, Martin Thompson, Jon Tibble, Dave Warnock,              #
+# Frode Woldsund, Martin Zibricky                                             #
 # --------------------------------------------------------------------------- #
 # This program is free software; you can redistribute it and/or modify it     #
 # under the terms of the GNU General Public License as published by the Free  #
@@ -157,7 +158,8 @@ class ThemeForm(QtGui.QWizard, Ui_ThemeWizard):
             u'outlineColorButton', self.outlineColorButton)
         self.mainAreaPage.registerField(
             u'outlineSizeSpinBox', self.outlineSizeSpinBox)
-        self.mainAreaPage.registerField(u'shadowCheckBox', self.shadowCheckBox)
+        self.mainAreaPage.registerField(
+            u'shadowCheckBox', self.shadowCheckBox)
         self.mainAreaPage.registerField(
             u'mainBoldCheckBox', self.mainBoldCheckBox)
         self.mainAreaPage.registerField(
@@ -168,8 +170,10 @@ class ThemeForm(QtGui.QWizard, Ui_ThemeWizard):
             u'shadowSizeSpinBox', self.shadowSizeSpinBox)
         self.mainAreaPage.registerField(
             u'footerSizeSpinBox', self.footerSizeSpinBox)
-        self.areaPositionPage.registerField(u'mainPositionX', self.mainXSpinBox)
-        self.areaPositionPage.registerField(u'mainPositionY', self.mainYSpinBox)
+        self.areaPositionPage.registerField(
+            u'mainPositionX', self.mainXSpinBox)
+        self.areaPositionPage.registerField(
+            u'mainPositionY', self.mainYSpinBox)
         self.areaPositionPage.registerField(
             u'mainPositionWidth', self.mainWidthSpinBox)
         self.areaPositionPage.registerField(
@@ -202,7 +206,8 @@ class ThemeForm(QtGui.QWizard, Ui_ThemeWizard):
         """
         Updates the lines on a page on the wizard
         """
-        self.mainLineCountLabel.setText(unicode(translate('OpenLP.ThemeForm',
+        self.mainLineCountLabel.setText(unicode(translate(
+            'OpenLP.ThemeWizard',
             '(approximately %d lines per slide)')) % int(lines))
 
     def resizeEvent(self, event=None):
@@ -224,6 +229,19 @@ class ThemeForm(QtGui.QWizard, Ui_ThemeWizard):
             self.previewBoxLabel.setFixedSize(pixmapWidth + 2 * frameWidth,
                 pixmapHeight + 2 * frameWidth)
 
+    def validateCurrentPage(self):
+        background_image = BackgroundType.to_string(BackgroundType.Image)
+        if self.page(self.currentId()) == self.backgroundPage and \
+            self.theme.background_type == background_image and \
+            self.imageFileEdit.text().isEmpty():
+            QtGui.QMessageBox.critical(self,
+                translate('OpenLP.ThemeWizard', 'Background Image Empty'),
+                translate('OpenLP.ThemeWizard', 'You have not selected a '
+                    'background image. Please select one before continuing.'))
+            return False
+        else:
+            return True
+
     def onCurrentIdChanged(self, pageId):
         """
         Detects Page changes and updates as appropriate.
@@ -521,7 +539,7 @@ class ThemeForm(QtGui.QWizard, Ui_ThemeWizard):
         images_filter = u'%s;;%s (*.*) (*)' % (
             images_filter, UiStrings().AllFiles)
         filename = QtGui.QFileDialog.getOpenFileName(self,
-            translate('OpenLP.ThemeForm', 'Select Image'), u'',
+            translate('OpenLP.ThemeWizard', 'Select Image'), u'',
             images_filter)
         if filename:
             self.theme.background_filename = unicode(filename)
@@ -603,14 +621,14 @@ class ThemeForm(QtGui.QWizard, Ui_ThemeWizard):
         self.theme.theme_name = unicode(self.field(u'name').toString())
         if not self.theme.theme_name:
             critical_error_message_box(
-                translate('OpenLP.ThemeForm', 'Theme Name Missing'),
-                translate('OpenLP.ThemeForm',
+                translate('OpenLP.ThemeWizard', 'Theme Name Missing'),
+                translate('OpenLP.ThemeWizard',
                 'There is no name for this theme. Please enter one.'))
             return
         if self.theme.theme_name == u'-1' or self.theme.theme_name == u'None':
             critical_error_message_box(
-                translate('OpenLP.ThemeForm', 'Theme Name Invalid'),
-                translate('OpenLP.ThemeForm',
+                translate('OpenLP.ThemeWizard', 'Theme Name Invalid'),
+                translate('OpenLP.ThemeWizard',
                 'Invalid theme name. Please enter one.'))
             return
         saveFrom = None
