@@ -4,13 +4,14 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2012 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2012 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2013 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
-# Meinert Jordan, Armin Köhler, Edwin Lunando, Joshua Miller, Stevan Pettit,  #
-# Andreas Preikschat, Mattias Põldaru, Christian Richter, Philip Ridout,      #
-# Simon Scudder, Jeffrey Smith, Maikel Stuivenberg, Martin Thompson, Jon      #
-# Tibble, Dave Warnock, Frode Woldsund                                        #
+# Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
+# Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
+# Christian Richter, Philip Ridout, Simon Scudder, Jeffrey Smith,             #
+# Maikel Stuivenberg, Martin Thompson, Jon Tibble, Dave Warnock,              #
+# Frode Woldsund, Martin Zibricky                                             #
 # --------------------------------------------------------------------------- #
 # This program is free software; you can redistribute it and/or modify it     #
 # under the terms of the GNU General Public License as published by the Free  #
@@ -35,7 +36,6 @@ import os
 import re
 from subprocess import Popen, PIPE
 import sys
-import time
 import urllib2
 
 from openlp.core.lib.settings import Settings
@@ -137,7 +137,7 @@ class AppLocation(object):
         else:
             path = AppLocation.get_directory(AppLocation.DataDir)
             check_directory_exists(path)
-        return path
+        return os.path.normpath(path)
 
     @staticmethod
     def get_section_data_path(section):
@@ -471,23 +471,48 @@ def get_uno_instance(resolver):
             + u'urp;StarOffice.ComponentContext')
 
 
-def format_time(text):
+def format_time(text, local_time):
     """
     Workaround for Python built-in time formatting fuction time.strftime().
 
     time.strftime() accepts only ascii characters. This function accepts
     unicode string and passes individual % placeholders to time.strftime().
     This ensures only ascii characters are passed to time.strftime().
+
+    ``text``
+        The text to be processed.
+    ``local_time``
+        The time to be used to add to the string.  This is a time object
     """
     def match_formatting(match):
-        return time.strftime(match.group())
+        return local_time.strftime(match.group())
     return re.sub('\%[a-zA-Z]', match_formatting, text)
 
 
+def locale_compare(string1, string2):
+    """
+    Compares two strings according to the current locale settings.
+
+    As any other compare function, returns a negative, or a positive value,
+    or 0, depending on whether string1 collates before or after string2 or
+    is equal to it. Comparison is case insensitive.
+    """
+    # Function locale.strcol() from standard Python library does not work
+    # properly on Windows and probably somewhere else.
+    return QtCore.QString.localeAwareCompare(string1.lower(), string2.lower())
+
+
+# For performance reasons provide direct reference to compare function
+# without wrapping it in another function making te string lowercase.
+# This is needed for sorting songs.
+locale_direct_compare = QtCore.QString.localeAwareCompare
+
+
 from languagemanager import LanguageManager
 from actions import ActionList
 
 __all__ = [u'AppLocation', u'get_application_version', u'check_latest_version',
     u'add_actions', u'get_filesystem_encoding', u'LanguageManager',
     u'ActionList', u'get_web_page', u'get_uno_command', u'get_uno_instance',
-    u'delete_file', u'clean_filename', u'format_time']
+    u'delete_file', u'clean_filename', u'format_time', u'locale_compare',
+    u'locale_direct_compare']
