@@ -4,13 +4,14 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2012 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2012 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2013 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
-# Meinert Jordan, Armin Köhler, Edwin Lunando, Joshua Miller, Stevan Pettit,  #
-# Andreas Preikschat, Mattias Põldaru, Christian Richter, Philip Ridout,      #
-# Simon Scudder, Jeffrey Smith, Maikel Stuivenberg, Martin Thompson, Jon      #
-# Tibble, Dave Warnock, Frode Woldsund                                        #
+# Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
+# Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
+# Christian Richter, Philip Ridout, Simon Scudder, Jeffrey Smith,             #
+# Maikel Stuivenberg, Martin Thompson, Jon Tibble, Dave Warnock,              #
+# Frode Woldsund, Martin Zibricky                                             #
 # --------------------------------------------------------------------------- #
 # This program is free software; you can redistribute it and/or modify it     #
 # under the terms of the GNU General Public License as published by the Free  #
@@ -49,6 +50,7 @@ class Controller(object):
         """
         self.is_live = live
         self.doc = None
+        self.hide_mode = None
         log.info(u'%s controller loaded' % live)
 
     def add_handler(self, controller, file, hide_mode, slide_no):
@@ -67,6 +69,7 @@ class Controller(object):
             # Inform slidecontroller that the action failed?
             return
         self.doc.slidenumber = slide_no
+        self.hide_mode = hide_mode
         if self.is_live:
             if hide_mode == HideMode.Screen:
                 Receiver.send_message(u'live_display_hide', HideMode.Screen)
@@ -78,7 +81,7 @@ class Controller(object):
             else:
                 self.doc.start_presentation()
                 Receiver.send_message(u'live_display_hide', HideMode.Screen)
-                self.doc.slidenumber = 0
+                self.doc.slidenumber = 1
                 if slide_no > 1:
                     self.slide(slide_no)
 
@@ -88,100 +91,134 @@ class Controller(object):
         Use the last slide number.
         """
         log.debug(u'Live = %s, activate' % self.is_live)
+        if not self.doc:
+            return False
         if self.doc.is_active():
-            return
+            return True
         if not self.doc.is_loaded():
             if not self.doc.load_presentation():
-                return
+                log.warn(u'Failed to activate %s' % self.doc.filepath)
+                return False
         if self.is_live:
             self.doc.start_presentation()
             if self.doc.slidenumber > 1:
                 if self.doc.slidenumber > self.doc.get_slide_count():
                     self.doc.slidenumber = self.doc.get_slide_count()
                 self.doc.goto_slide(self.doc.slidenumber)
+        if self.doc.is_active():
+            return True
+        else:
+            log.warn(u'Failed to activate %s' % self.doc.filepath)
+            return False
 
     def slide(self, slide):
         """
         Go to a specific slide
         """
         log.debug(u'Live = %s, slide' % self.is_live)
+        if not self.doc:
+            return
         if not self.is_live:
             return
-        if self.doc.is_blank():
+        if self.hide_mode:
             self.doc.slidenumber = int(slide) + 1
+            self.poll()
+            return
+        if not self.activate():
             return
-        self.activate()
         self.doc.goto_slide(int(slide) + 1)
-        self.doc.poll_slidenumber(self.is_live)
+        self.poll()
 
     def first(self):
         """
         Based on the handler passed at startup triggers the first slide
         """
         log.debug(u'Live = %s, first' % self.is_live)
+        if not self.doc:
+            return
         if not self.is_live:
             return
-        if self.doc.is_blank():
+        if self.hide_mode:
             self.doc.slidenumber = 1
+            self.poll()
+            return
+        if not self.activate():
             return
-        self.activate()
         self.doc.start_presentation()
-        self.doc.poll_slidenumber(self.is_live)
+        self.poll()
 
     def last(self):
         """
         Based on the handler passed at startup triggers the last slide
         """
         log.debug(u'Live = %s, last' % self.is_live)
+        if not self.doc:
+            return
         if not self.is_live:
             return
-        if self.doc.is_blank():
+        if self.hide_mode:
             self.doc.slidenumber = self.doc.get_slide_count()
+            self.poll()
+            return
+        if not self.activate():
             return
-        self.activate()
         self.doc.goto_slide(self.doc.get_slide_count())
-        self.doc.poll_slidenumber(self.is_live)
+        self.poll()
 
     def next(self):
         """
         Based on the handler passed at startup triggers the next slide event
         """
         log.debug(u'Live = %s, next' % self.is_live)
+        if not self.doc:
+            return
         if not self.is_live:
             return
-        if self.doc.is_blank():
+        if self.hide_mode:
+            if not self.doc.is_active():
+                return
             if self.doc.slidenumber < self.doc.get_slide_count():
                 self.doc.slidenumber = self.doc.slidenumber + 1
+                self.poll()
+            return
+        if not self.activate():
             return
         # The "End of slideshow" screen is after the last slide
         # Note, we can't just stop on the last slide, since it may
         # contain animations that need to be stepped through.
         if self.doc.slidenumber > self.doc.get_slide_count():
             return
-        self.activate()
         self.doc.next_step()
-        self.doc.poll_slidenumber(self.is_live)
+        self.poll()
 
     def previous(self):
         """
         Based on the handler passed at startup triggers the previous slide event
         """
         log.debug(u'Live = %s, previous' % self.is_live)
+        if not self.doc:
+            return
         if not self.is_live:
             return
-        if self.doc.is_blank():
+        if self.hide_mode:
+            if not self.doc.is_active():
+                return
             if self.doc.slidenumber > 1:
                 self.doc.slidenumber = self.doc.slidenumber - 1
+                self.poll()
+            return
+        if not self.activate():
             return
-        self.activate()
         self.doc.previous_step()
-        self.doc.poll_slidenumber(self.is_live)
+        self.poll()
 
     def shutdown(self):
         """
         Based on the handler passed at startup triggers slide show to shut down
         """
         log.debug(u'Live = %s, shutdown' % self.is_live)
+        if not self.doc:
+            return
         self.doc.close_presentation()
         self.doc = None
 
@@ -190,21 +227,30 @@ class Controller(object):
         Instruct the controller to blank the presentation
         """
         log.debug(u'Live = %s, blank' % self.is_live)
+        self.hide_mode = hide_mode
+        if not self.doc:
+            return
         if not self.is_live:
             return
-        if not self.doc.is_loaded():
-            return
-        if not self.doc.is_active():
-            return
         if hide_mode == HideMode.Theme:
+            if not self.doc.is_loaded():
+                return
+            if not self.doc.is_active():
+                return
             Receiver.send_message(u'live_display_hide', HideMode.Theme)
-        self.doc.blank_screen()
+        elif hide_mode == HideMode.Blank:
+            if not self.activate():
+                return
+            self.doc.blank_screen()
 
     def stop(self):
         """
         Instruct the controller to stop and hide the presentation
         """
         log.debug(u'Live = %s, stop' % self.is_live)
+        self.hide_mode = HideMode.Screen
+        if not self.doc:
+            return
         if not self.is_live:
             return
         if not self.doc.is_loaded():
@@ -218,9 +264,13 @@ class Controller(object):
         Instruct the controller to unblank the presentation
         """
         log.debug(u'Live = %s, unblank' % self.is_live)
+        self.hide_mode = None
+        if not self.doc:
+            return
         if not self.is_live:
             return
-        self.activate()
+        if not self.activate():
+            return
         if self.doc.slidenumber and \
             self.doc.slidenumber != self.doc.get_slide_number():
             self.doc.goto_slide(self.doc.slidenumber)
@@ -228,7 +278,9 @@ class Controller(object):
         Receiver.send_message(u'live_display_hide', HideMode.Screen)
 
     def poll(self):
-        self.doc.poll_slidenumber(self.is_live)
+        if not self.doc:
+            return
+        self.doc.poll_slidenumber(self.is_live, self.hide_mode)
 
 
 class MessageListener(object):
@@ -278,7 +330,7 @@ class MessageListener(object):
         item = message[0]
         log.debug(u'Startup called with message %s' % message)
         hide_mode = message[2]
-        file = os.path.join(item.get_frame_path(), item.get_frame_title())
+        file = item.get_frame_path()
         self.handler = item.title
         if self.handler == self.mediaitem.Automatic:
             self.handler = self.mediaitem.findControllerByType(file)
